@@ -21,6 +21,7 @@
 #include <config.h>
 #endif
 
+#include "actions.h"
 #include "comment.h"
 #include "gui.h"
 #include "nautilus-string.h"
@@ -233,6 +234,17 @@ GtrComment *gtranslator_comment_copy(GtrComment **comment)
 	return copy;
 }
 
+/*
+ * Returns the "normal" and plain comment contents string.
+ */
+gchar *gtranslator_comment_get_comment_contents(GtrComment *comment)
+{
+	g_return_val_if_fail(GTR_COMMENT(comment)!=NULL, "");
+	g_return_val_if_fail(GTR_COMMENT(comment)->comment!=NULL, "");
+
+	return (GTR_COMMENT(comment)->comment);
+}
+
 /*
  * Free the GtrComment.
  */
@@ -295,16 +307,12 @@ void gtranslator_comment_display(GtrComment *comment)
 	{
 		if(!GtrPreferences.show_comment)
 		{
-			comment_display_str=" ";
-		}
-		else if(strlen(comment->pure_comment) > 82)
-		{
-			comment_display_str=nautilus_str_middle_truncate(
-				comment->pure_comment, 82);
+			comment_display_str=g_strdup(" ");
 		}
 		else
 		{
-			comment_display_str=comment->pure_comment;
+			comment_display_str=nautilus_str_middle_truncate(
+				comment->pure_comment, 82);
 		}
 	}
 
@@ -316,12 +324,16 @@ void gtranslator_comment_display(GtrComment *comment)
 		nautilus_strcasecmp(comment_display_str, " "))
 	{
 		gtk_widget_set_sensitive(extra_content_view->edit_button, TRUE);
+		gtranslator_actions_enable(ACT_COMMENT);
 	}
 	else
 	{
 		gtk_widget_set_sensitive(extra_content_view->edit_button, FALSE);
+		gtranslator_actions_disable(ACT_COMMENT);
 	}
 
+	g_free(comment_display_str);
+
 	e_paned_set_position(E_PANED(content_pane), 0);
 }
 
