@@ -68,8 +68,8 @@ GtrComment *gtranslator_comment_new(const gchar *comment_string);
 void gtranslator_comment_append(GtrComment **comment, const gchar *comment_string);
 
 /*
- * Assign the given full_comment (which must be a full comment string _with_ prefix)
- *  to the comment and update the comment informations/fields.
+ * Assign the given full_comment (which must be a full comment string _with_ 
+ *  prefix) to the comment and update the comment informations/fields.
  */
 void gtranslator_comment_update(GtrComment **comment, const gchar *full_comment);
 
@@ -83,6 +83,11 @@ gboolean gtranslator_comment_search(GtrComment *comment, const gchar *search_str
  */
 GtrComment *gtranslator_comment_copy(GtrComment **comment); 
 
+/*
+ * Return a savely copy of the comment contents by itself.
+ */
+gchar *gtranslator_comment_get_comment_contents(GtrComment *comment);
+
 /*
  * Free the GtrComment.
  */
