@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
@@ -28,12 +28,13 @@
 #include "dialogs.h"
 #include "find.h"
 #include "gui.h"
+#include "learn.h"
 #include "message.h"
+#include "messages-table.h"
 #include "nautilus-string.h"
 #include "open.h"
 #include "parse.h"
 #include "prefs.h"
-#include "query.h"
 #include "replace.h"
 #include "runtime-config.h"
 #include "syntax.h"
@@ -111,7 +112,7 @@ void gtranslator_open_file_dialog(GtkWidget * widget, gpointer useless)
 	 *  because it is not a GnomeDialog.
 	 */
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(gtranslator_application));
-	gtranslator_dialog_show(&dialog, "gtranslator -- open");
+	gtranslator_dialog_show(&dialog, NULL );
 }
 
 /*
@@ -521,22 +522,23 @@ void gtranslator_file_dialogs_set_directory(GtkWidget **fileselection)
 	if(po && po->filename)
 	{
 		directory=g_dirname(po->filename);
-		gtk_file_selection_complete(GTK_FILE_SELECTION(*fileselection), directory);
+		gtk_file_selection_complete(GTK_FILE_SELECTION(*fileselection),
+			directory);
 	}
 	else
 	{
-		gtranslator_config_init();
 		directory=gtranslator_config_get_string("informations/last_directory");
-		gtranslator_config_close();
 
-		if(directory)
+		if(directory && g_file_test(directory, G_FILE_TEST_ISDIR))
 		{
-			gtk_file_selection_complete(GTK_FILE_SELECTION(*fileselection), directory);
+			gtk_file_selection_complete(
+				GTK_FILE_SELECTION(*fileselection), directory);
 		}
 		else
 		{
 			directory=g_get_home_dir();
-			gtk_file_selection_complete(GTK_FILE_SELECTION(*fileselection), directory);
+			gtk_file_selection_complete(
+				GTK_FILE_SELECTION(*fileselection), directory);
 		}
 	}
 
@@ -554,9 +556,7 @@ void gtranslator_file_dialogs_store_directory(const gchar *filename)
 	
 	directory=g_dirname(filename);
 	
-	gtranslator_config_init();
 	gtranslator_config_set_string("informations/last_directory", directory);
-	gtranslator_config_close();
 
 	GTR_FREE(directory);
 }
@@ -635,19 +635,15 @@ static void match_case_toggled(GtkWidget * widget, gpointer useless)
 	GtrPreferences.match_case =
 	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gtranslator_update_regex_flags();
-	gtranslator_config_init();
 	gtranslator_config_set_bool("find/case_sensitive",
 			      GtrPreferences.match_case);
-	gtranslator_config_close();
 }
 
 static void find_in_activated(GtkWidget * widget, gpointer which)
 {
 	GtrPreferences.find_in = GPOINTER_TO_INT(which);
-	gtranslator_config_init();
 	gtranslator_config_set_int("find/find_in",
 			      GtrPreferences.find_in);
-	gtranslator_config_close();
 }
 
 static void find_dlg_clicked(GnomeDialog * dialog, gint button,
@@ -1010,7 +1006,8 @@ like \"http\", \"ftp\" or any other access method supported by GnomeVFS."
 "Some example URIs for clarification (these ones are supported):\n\
 http://www.gtranslator.org/remote-po/gtranslator.pot\n\
 ftp://anonymous@ftp.somewhere.com/<A-REMOTE-PO-FILE>\n\n\
-file:///<PO-FILE>"));
+file:///<PO-FILE> or\n\
+http://www.DOMAIN.COM/PO-FILE"));
 	}
 	else
 	{
@@ -1034,9 +1031,7 @@ void gtranslator_rescue_file_dialog(void)
 	/*
 	 * Get the original filename for the crash-file from the prefs.
 	 */
-	gtranslator_config_init();
 	original_filename=gtranslator_config_get_string("crash/filename");
-	gtranslator_config_close();
 
 	recovery_message=g_strdup_printf(_("Open recovery file for `%s'?\n\
 It was saved by gtranslator before gtranslator last closed\n\
@@ -1089,12 +1084,12 @@ Saying \"No\" will delete the crash recovery file."),
 void gtranslator_query_dialog(void)
 {
 	static GtkWidget *dialog=NULL;
+
 	GtkWidget *innertable;
 	GtkWidget *query_entry;
 	GtkWidget *query_entry_label;
-	GtkWidget *domain;
-	GtkWidget *domain_label;
 	GtkWidget *label;
+
 	gint reply;
 	
 	gtranslator_raise_dialog(dialog);
@@ -1105,20 +1100,15 @@ void gtranslator_query_dialog(void)
 	#define add2Table(x, y, z); \
 	gtk_table_attach_defaults(GTK_TABLE(innertable), x, y, y+1, z, z+1);
 
-	if(!domains)
-	{
-		gtranslator_utils_error_dialog(_("Couldn't get list of gettext domains!"));
-		return;
-	}
-
 	/*
 	 * A half-baken dialog for the query functionality.
 	 */
-	label=gtk_label_new(_("Here you can query existing gettext domains for a translation."));
+	label=gtk_label_new(_("Here you can query existing translations from your learn buffer."));
 	
 	dialog=gnome_dialog_new(
-		_("gtranslator -- query existing gettext domains"),
-		_("Query"), GNOME_STOCK_BUTTON_CLOSE, NULL);
+		_("gtranslator -- query your personal learn buffer"),
+		_("Query"), _("Query message content"),
+		GNOME_STOCK_BUTTON_CLOSE, NULL);
 
 	innertable=gtk_table_new(2, 2, FALSE);
 
@@ -1128,22 +1118,6 @@ void gtranslator_query_dialog(void)
 	query_entry=gnome_entry_new("QUERY");
 	query_entry_label=gtk_label_new(_("Query string:"));
 
-	/*
-	 * Setup our loved domains list as the stringlist for the combobox.
-	 */
-	domain=gtk_combo_new();
-	gtk_combo_set_popdown_strings(GTK_COMBO(domain), domains);
-	domain_label=gtk_label_new(_("Domain to search the translation in:"));
-
-	/*
-	 * Set up the default query domain from the preferences if available.
-	 */
-	if(gtranslator_translator->query_domain)
-	{
-		gtk_entry_set_text(GTK_ENTRY(
-			GTK_COMBO(domain)->entry), gtranslator_translator->query_domain);
-	}
-
 	/*
 	 * Add the widgets to the dialog.
 	 */
@@ -1152,8 +1126,6 @@ void gtranslator_query_dialog(void)
 
 	add2Table(query_entry_label, 0, 0);
 	add2Table(query_entry, 1, 0);
-	add2Table(domain_label, 0, 1);
-	add2Table(domain, 1, 1);
 
 	/*
 	 * "Query" should be the default button I guess.
@@ -1163,19 +1135,26 @@ void gtranslator_query_dialog(void)
 
 	reply=gnome_dialog_run(GNOME_DIALOG(dialog));
 
-	if(reply==GNOME_CANCEL)
+	if(reply==2)
 	{
 		gnome_dialog_close(GNOME_DIALOG(dialog));
 	}
-	else if(reply==GNOME_YES)
+	else if(reply==1 || !reply)
 	{
 		gchar *query_text;
 	
 		/*
 		 * Get the string to query for from the GnomeEntry.
 		 */
-		query_text=gtk_editable_get_chars(GTK_EDITABLE(
-		gnome_entry_gtk_entry(GNOME_ENTRY(query_entry))), 0, -1);
+		if(!reply)
+		{
+			query_text=gtk_editable_get_chars(GTK_EDITABLE(
+				gnome_entry_gtk_entry(GNOME_ENTRY(query_entry))), 0, -1);
+		}
+		else
+		{
+			query_text=g_strdup(GTR_MSG(po->current->data)->msgid);
+		}
 
 		if(!query_text || (strlen(query_text) <= 1))
 		{
@@ -1190,28 +1169,9 @@ void gtranslator_query_dialog(void)
 		}
 		else
 		{
-			GtrQuery *query;
-			GtrQuery *result;
-			gchar *domainname;
+			gchar *result;
 
-			/*
-			 * Get the domain's name from the combobox.
-			 */
-			domainname=gtk_editable_get_chars(GTK_EDITABLE(
-				GTK_COMBO(domain)->entry), 0, -1);
-
-			/*
-			 * Build up and run the query.
-			 */
-			query=gtranslator_new_query(domainname, query_text, 
-				gtranslator_translator->language->locale);
-			result=gtranslator_query_simple(query);
-		
-			/*
-			 * Stop the leaking! Free the used gchars!
-			 */
-			GTR_FREE(query_text);
-			GTR_FREE(domainname);
+			result=gtranslator_learn_get_learned_string(query_text);
 			
 			/*
 			 * Close the open dialog now.
@@ -1224,54 +1184,23 @@ void gtranslator_query_dialog(void)
 				 * No results? Close down the dialog.
 				 */
 				gnome_app_warning(GNOME_APP(gtranslator_application),
-				_("Couldn't find any result for the query!"));
+					_("Couldn't find any result for the query in your learn buffer!"));
 			}
 			else
 			{
 				/*
-				 * In the other case simply print out the
-				 *  found translation with the domain name for 
-				 *   now and close/exit then.
+				 * In the other case simply print out the found
+				 *  translation and exit then.
 				 */
 				gchar *resulttext;
 				GtkWidget *condialog=NULL;
 				gint hehue;
 
-				resulttext=g_strdup_printf(_("Found \"%s\" as a translation for \"%s\" in domain \"%s\".\n\
+				resulttext=g_strdup_printf(_("Found \"%s\" as a translation for \"%s\".\n\
 Would you like to insert it into the translation?"),
-					result->message, query->message, result->domain);
+					result, query_text);
 
-				/*
-				 * Set the last query result in the prefs for
-				 *  persistence.
-				 */
-				gtranslator_config_init();
-				
-				gtranslator_config_set_string(
-					"query/last_match_filename",
-					po->filename);
-				
-				gtranslator_config_set_int(
-					"query/last_match_message_no",
-					g_list_position(po->messages, 
-						po->current));
-				
-				gtranslator_config_set_string(
-					"query/last_match_domain", 
-					result->domain);
-				
-				gtranslator_config_set_string(
-					"query/last_match_message", 
-					query->message);
-				
-				gtranslator_config_set_string(
-					"query/last_match_translation", 
-					result->message);
-				
-				gtranslator_config_close();
-
-				gtranslator_free_query(&query);
-				
+				GTR_FREE(query_text);
 
 				/*
 				 * Build up another dialog and show up the
@@ -1307,25 +1236,32 @@ Would you like to insert it into the translation?"),
 					 *  translation box; if so print a warning
 					 *   and don't insert the translation.
 					 */
-					if(content && strcmp(content, result->message))
+					if(content && nautilus_strcasecmp(content, result))
 					{
 						/*
 						 * Insert the text and update the
 						 * status flags for it.
 						 */
-						gtranslator_syntax_insert_text(trans_box,
-						result->message);
+						gtk_text_insert(GTK_TEXT(trans_box), NULL, NULL, NULL,
+							result, strlen(result));
 
 						gtranslator_translation_changed(NULL, NULL);
 
-						gtranslator_free_query(&result);
+						gtranslator_message_update();
+						if(GtrPreferences.show_messages_table)
+						{
+							gtranslator_messages_table_update_message_status(GTR_MSG(po->current->data));
+						}
+
+						GTR_FREE(result);
 					}
 					else
 					{
 						gnome_app_warning(GNOME_APP(gtranslator_application),
+
 						/*
-						 * Translators: This means that the queried string
-						 *  is already translated.
+						 * Translators: This means that the query result string is
+						 *  already translated.
 						 */
 						_("Query's result translation is already there!"));
 					}
@@ -1348,16 +1284,8 @@ void gtranslator_auto_translation_dialog(void)
 
 	gtranslator_raise_dialog(dialog);
 
-	if(GtrPreferences.use_learn_buffer)
-	{
-		message_string=_("Should gtranslator autotranslate the file using information\n\
-from the default query domain and the personal learn buffer?");
-	}
-	else
-	{
-		message_string=_("Should gtranslator autotranslate the file using information\n\
-from the default query domain?");
-	}
+	message_string=_("Should gtranslator autotranslate the file using information\n\
+from your personal learn buffer?");
 
 	dialog=gnome_message_box_new(message_string,
 		GNOME_MESSAGE_BOX_QUESTION,
@@ -1365,7 +1293,6 @@ from the default query domain?");
 		GNOME_STOCK_BUTTON_NO,
 		NULL);
 
-
 	/*
 	 * Set the default to "Yes" and show/run the dialog.
 	 */
@@ -1382,6 +1309,6 @@ from the default query domain?");
 		/*
 		 * Autotranslate the missing entries.
 		 */
-		gtranslator_query_translate(GtrPreferences.use_learn_buffer, TRUE);
+		gtranslator_learn_autotranslate(TRUE);
 	}
 }
