@@ -1,6 +1,7 @@
 /*
  * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
+ *			Peeter Vois <peeter@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,14 +41,12 @@
 #include "parse.h"
 #include "prefs.h"
 #include "runtime-config.h"
-#include "sidebar.h"
 #include "stylistics.h"
 #include "syntax.h"
 #include "translator.h"
 #include "undo.h"
 #include "utils.h"
 #include "utils_gui.h"
-#include "views.h"
 
 #include <string.h>
 
@@ -81,7 +80,6 @@ GtkWidget *trans_box;
 GtkWidget *text_box;
 GtkWidget *gtranslator_application_bar;
 
-GtkWidget *sidebar_pane;
 GtkWidget *content_pane;
 GtkWidget *table_pane;
 
@@ -90,11 +88,6 @@ GtkWidget *table_pane;
  */
 GtrExtraContentArea *extra_content_view;
 
-/*
- * Internally used local-global variables
- */
-static GtkWidget *views_sidebar;
-
 gboolean nothing_changes;
 
 /*
@@ -106,10 +99,10 @@ static gint create_popup_menu(GtkText *widget, GdkEventButton *event,
 /*
  * Internal text callbacks/handlers.
  */
-static void insert_text_handler (GtkEditable *editable, const gchar *text,
+void insert_text_handler (GtkEditable *editable, const gchar *text,
 	gint length, gint *position, gpointer data);
 
-static void delete_text_handler(GtkEditable *editable, gint start_position,
+void delete_text_handler(GtkEditable *editable, gint start_position,
 	gint end_position);
 
 static void selection_get_handler(GtkWidget *widget,
@@ -133,12 +126,10 @@ static  GtkTargetEntry dragtypes[] = {
 /*
  * Counts the already performed update's count for the syntax updating.
  */
-static gint 	update_count=0;
 
 /*
  * Pane positions storage variables.
  */
-static gint 	sidebar_pane_position;
 static gint	table_pane_position;
 
 /*
@@ -182,6 +173,8 @@ void gtranslator_create_main_window(void)
 	
 	GtkWidget *original_text_scrolled_window;
 	GtkWidget *translation_text_scrolled_window;
+	GtkWidget *comments_scrolled_window;
+	GtkWidget *comments_viewport;
 
 	/*
 	 * Create the app	
@@ -192,14 +185,9 @@ void gtranslator_create_main_window(void)
 	/*
 	 * Create all the panes we're using later on.
 	 */
-	sidebar_pane=e_hpaned_new();
 	content_pane=e_vpaned_new();
 	table_pane=e_hpaned_new();
 	
-	/*
-	 * Create the sidebars and/or messages table.
-	 */
-	views_sidebar=gtranslator_sidebar_new();
 
 	if(GtrPreferences.show_messages_table)
 	{
@@ -213,24 +201,6 @@ void gtranslator_create_main_window(void)
 		gtranslator_messages_table=gtk_label_new("");
 	}
 
-	gtranslator_config_init();
-
-	/*
-	 * Activate the paned widgets if desired and set the pane gutter to
-	 *  the right place.
-	 */
-	if(GtrPreferences.show_sidebar)
-	{
-		sidebar_pane_position=gtranslator_config_get_int(
-			"interface/sidebar_pane_position");
-		
-		e_paned_set_position(E_PANED(sidebar_pane), sidebar_pane_position);
-	}
-	else
-	{
-		e_paned_set_position(E_PANED(sidebar_pane), -1);
-	}
-
 	if(GtrPreferences.show_messages_table)
 	{
 		table_pane_position=gtranslator_config_get_int(
@@ -243,20 +213,28 @@ void gtranslator_create_main_window(void)
 		e_paned_set_position(E_PANED(table_pane), -1);
 	}
 	
-	gtranslator_config_close();
-
 	extra_content_view=g_new0(GtrExtraContentArea, 1);
 	
 	extra_content_view->box=gtk_hbox_new(FALSE, 1);
+	
+	comments_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(comments_scrolled_window),
+				       GTK_POLICY_NEVER,
+				       GTK_POLICY_AUTOMATIC);
+	gtk_box_pack_start(GTK_BOX(extra_content_view->box), comments_scrolled_window, TRUE, TRUE, 0);
+	
+	comments_viewport = gtk_viewport_new(NULL, NULL);
+	gtk_widget_show(comments_viewport);
+	gtk_container_add(GTK_CONTAINER(comments_scrolled_window), comments_viewport);
+	
 	extra_content_view->comment=gtk_label_new("");
+	gtk_container_add(GTK_CONTAINER(comments_viewport), extra_content_view->comment);
+	
 	extra_content_view->edit_button=gtk_button_new_with_label(_("Edit comment"));
-
-	gtk_box_pack_start(GTK_BOX(extra_content_view->box), extra_content_view->comment, 
-		FALSE, FALSE, 0);
-	gtk_box_pack_end(GTK_BOX(extra_content_view->box), extra_content_view->edit_button, 
+	gtk_widget_set_sensitive(extra_content_view->edit_button, FALSE);
+	gtk_box_pack_end(GTK_BOX(extra_content_view->box), extra_content_view->edit_button,
 		FALSE, FALSE, 0);
 	
-	gtk_widget_set_sensitive(extra_content_view->edit_button, FALSE);
 	e_paned_set_position(E_PANED(content_pane), 0);
 
 	/*
@@ -288,9 +266,7 @@ void gtranslator_create_main_window(void)
 	e_paned_pack1(E_PANED(table_pane), gtranslator_messages_table, TRUE, FALSE);
 	e_paned_pack2(E_PANED(table_pane), content_pane, TRUE, FALSE);
 	
-	e_paned_pack1(E_PANED(sidebar_pane), views_sidebar, TRUE, FALSE);
-	e_paned_pack2(E_PANED(sidebar_pane), table_pane, TRUE, FALSE);
-	gnome_app_set_contents(GNOME_APP(gtranslator_application), sidebar_pane);
+	gnome_app_set_contents(GNOME_APP(gtranslator_application), table_pane);
 
 	original_text_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_box_pack_start(GTK_BOX(vertical_box), original_text_scrolled_window, TRUE, TRUE, 0);
@@ -329,11 +305,13 @@ void gtranslator_create_main_window(void)
 	/*
 	 * Set up our special styles for the text boxes.
 	 */
-	gtranslator_config_init();
 	gtranslator_set_style(text_box, 0);
 	gtranslator_set_style(trans_box, 1);
-	gtranslator_config_close();
-	
+	/*
+	 *  Initialize highlighting
+	 */
+	 gtranslator_syntax_init(GTK_EDITABLE(trans_box));
+	 gtranslator_syntax_init(GTK_EDITABLE(text_box));
 	/*
 	 * The callbacks list
 	 */
@@ -348,6 +326,12 @@ void gtranslator_create_main_window(void)
 	gtk_signal_connect_after(GTK_OBJECT(trans_box), "selection_get",
 			   GTK_SIGNAL_FUNC(selection_get_handler), NULL);
 
+	gtk_signal_connect(GTK_OBJECT(text_box), "insert_text",
+			   GTK_SIGNAL_FUNC(insert_text_handler), NULL);
+	gtk_signal_connect(GTK_OBJECT(text_box), "delete_text",
+			   GTK_SIGNAL_FUNC(delete_text_handler), NULL);
+
+
 	gtk_signal_connect(GTK_OBJECT(trans_box), "insert_text",
 			   GTK_SIGNAL_FUNC(insert_text_handler), NULL);
 	gtk_signal_connect(GTK_OBJECT(trans_box), "delete_text",
@@ -379,7 +363,7 @@ void gtranslator_create_main_window(void)
  * An own delete text handler which should work on deletion in the translation
  *  box -- undo is called up here, too.
  */
-static void delete_text_handler(GtkEditable *editable, gint start_position,
+void delete_text_handler(GtkEditable *editable, gint start_position,
 	gint end_position)
 {
 	/*
@@ -399,6 +383,9 @@ static void delete_text_handler(GtkEditable *editable, gint start_position,
 		gtranslator_undo_register_deletion(fake_string, start_position);
 		GTR_FREE(fake_string);
 	}
+//	gtranslator_delete_highlighted(editable, 
+//			start_position, end_position - start_position);
+//	gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "delete_text");
 }
 
 /*
@@ -414,17 +401,6 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 		return TRUE;
 
 	gtranslator_file_close(NULL, NULL);
-	
-	/*
-	 * Initialize the config and set the pane positions -- if needed.
-	 */
-	gtranslator_config_init();
-
-	if(GtrPreferences.show_sidebar)
-	{
-		sidebar_pane_position=e_paned_get_position(E_PANED(sidebar_pane));
-		gtranslator_config_set_int("interface/sidebar_pane_position", sidebar_pane_position);
-	}
 
 	/*
 	 * Get the EPaned's position offset.
@@ -473,6 +449,12 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 	 */
 	gtranslator_preferences_free();
 
+	/*
+	 * Now clean up the list of all colorschemes -- should be safe to do it
+	 *  here if we've already shut down most of the GUI elements.
+	 */
+	gtranslator_color_scheme_delete_schemes_list();
+
 	/*
 	 * Remove any lungering temp. file.
 	 */
@@ -487,7 +469,6 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 	 * Store the current date.
 	 */
 	gtranslator_config_set_last_run_date();
-	gtranslator_config_close();
 
 	/*
 	 * Free our used content area variable on exit .-)
@@ -554,7 +535,7 @@ void gtranslator_application_bar_update(gint pos)
 			gtranslator_actions_disable(ACT_NEXT_FUZZY);
 		}
 	} else if(msg->status & GTR_MSG_STATUS_STICK) {
-		status=g_strdup(_("Stick"));
+		status=g_strdup(_("Sticky (Message & translation are the same)"));
 	} else if(msg->status & GTR_MSG_STATUS_TRANSLATED) {
 		status=g_strdup(_("Translated"));
 	} else {
@@ -652,48 +633,11 @@ void gtranslator_translation_changed(GtkWidget  * widget, gpointer useless)
 		     && (msg->status & GTR_MSG_STATUS_FUZZY))
 		{
 		     	gtranslator_message_status_set_fuzzy(msg, FALSE);
-			if(GtrPreferences.show_messages_table)
-			{
-				gtranslator_messages_table_update_message_status(msg);
-			}
 			gtranslator_actions_disable_fuzzy_menu_item();
 		}
-	}
-
-	if(widget)
-	{
-		gint selpos=0;
-
-		update_count++;
-
-		/*
-		 * Check if there were already made an update -- don't update
-		 *  the syntax 3x for only one reason/change.
-		 */
-		if(update_count >= 2)
+		if(GtrPreferences.show_messages_table)
 		{
-			update_count=0;
-			return;
-		}
-	
-		/*
-		 * Determine any selections the translation box currently owns.
-		 */
-		if(GTK_EDITABLE(widget)->has_selection)
-		{
-			selpos=gtk_text_get_point(GTK_TEXT(widget));
-		}
-		
-		gtranslator_syntax_update_text(widget);
-
-		/*
-		 * If there were any position from the selection we can 
-		 *  now again go there.
-		 */
-		if(selpos > 0)
-		{
-			gtk_text_set_point(GTK_TEXT(widget), selpos);
-			selpos=0;
+			gtranslator_messages_table_update_message_status(msg);
 		}
 	}
 }
@@ -704,39 +648,25 @@ void gtranslator_translation_changed(GtkWidget  * widget, gpointer useless)
 void insert_text_handler (GtkEditable *editable, const gchar *text,
 			  gint length, gint *position, gpointer data)
 {
-	gchar *result;
+//	gchar *result;
 
-	if (nothing_changes)
-		return;
-		
-	/*
-	 * Do all these steps only if the option to use the '' is set.
-	 */
-	if(!GtrPreferences.dot_char)
-		return;
+//	result=g_strdup(text);
+	if (!nothing_changes)
+	{
+		/*
+		* Register the text for an insertion undo action.
+		*/
+		gtranslator_undo_register_insertion(text, *position);
 
-	result=g_strdup(text);
-
-	/*
-	 * Register the text for an insertion undo action.
-	 */
-	gtranslator_undo_register_insertion(result, *position);
-	
-	gtranslator_utils_invert_dot(result);
-	
-	gtk_signal_handler_block_by_func(GTK_OBJECT(editable),
-					 GTK_SIGNAL_FUNC(insert_text_handler),
-					 data);
-	
-	gtk_editable_insert_text(editable, result, length, position);
-	
-	gtk_signal_handler_unblock_by_func(GTK_OBJECT(editable),
-					   GTK_SIGNAL_FUNC(insert_text_handler),
-					   data);
-	
-	gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
-
-	GTR_FREE(result);
+		if(GtrPreferences.dot_char)
+		{
+			gtranslator_utils_invert_dot((gchar*)text);
+		}
+	}
+//	gtranslator_insert_highlighted(editable, result, position, length);
+//	g_free(result);
+//	gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
+//	gtk_editable_set_position(GTK_EDITABLE(editable), *position);
 }
 
 void selection_get_handler(GtkWidget *widget, GtkSelectionData *selection_data,
@@ -751,7 +681,7 @@ void selection_get_handler(GtkWidget *widget, GtkSelectionData *selection_data,
 	gtranslator_utils_invert_dot(text);
 	gtk_selection_data_set(selection_data, selection_data->type,
 			       8, text, strlen(text));
-	GTR_FREE(text);
+	g_free(text);
 }
 
 /*
@@ -821,11 +751,3 @@ static gint gtranslator_keyhandler(GtkWidget *widget, GdkEventKey *event)
 	
 	return TRUE;
 }
-
-/*
- * Switch to the given view.
- */
-void gtranslator_switch_views(GtkWidget *widget, gpointer view)
-{
-	gtranslator_views_set(GPOINTER_TO_INT(view));
-}
