@@ -521,6 +521,13 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 				    encodings_list, ph->charset,
 				    FALSE,
 				    gtranslator_header_edit_changed, NULL);
+
+	/*
+	 * Disable any charset changes directly from the header by making the
+	 *  charset combo non-editable.
+	 */
+	gtk_widget_set_sensitive(GTK_WIDGET(charset_combo), FALSE);
+
 	enc_combo =
 	    gtranslator_utils_attach_combo_with_label(lang_page, 6, _("Encoding:"),
 				    bits_list, ph->encoding,
@@ -573,10 +580,8 @@ static void take_my_options_toggled(GtkWidget * widget, gpointer useless)
 {
 	GtrPreferences.fill_header =
 	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(take_my_options));
-	gtranslator_config_init();
 	gtranslator_config_set_bool("toggles/fill_header",
 			      GtrPreferences.fill_header);
-	gtranslator_config_close();
 	
 	gtk_widget_set_sensitive(lang_page, !GtrPreferences.fill_header);
 	gtranslator_header_edit_changed(widget, useless);
