@@ -40,7 +40,7 @@ GtrLanguage languages[] = {
 	 "", "8bit"
 	},
 	{
-	 N_("Azerbaijani Turkish"), "az", "utf-8",
+	 N_("Azerbaijani Turkish"), "az", "UTF-8",
 	 "linuxaz@azerimal.net", "8bit"
 	},
 	{
@@ -181,7 +181,7 @@ GtrLanguage languages[] = {
 	},
 	{
 	 N_("Norwegian/Nynorsk"), "nn", "iso-8859-1",
-	 "no@li.org", "8bit"
+	 "nn@li.org", "8bit"
 	},
 	{
 	 N_("Polish"), "pl", "iso-8859-2",
@@ -244,7 +244,7 @@ GtrLanguage languages[] = {
 	 "", "8bit"
 	},
 	{
-	 N_("Turkish"), "tr", "iso-8859-9",
+	 N_("Turkish"), "tr", "ISO-8859-9",
 	 "gnome-turk@gnome.org", "8bit"
 	},
 	{
