@@ -1,5 +1,5 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,10 @@
 #include <config.h>
 #endif
 
+#include "actions.h"
 #include "learn.h"
+#include "message.h"
+#include "messages-table.h"
 #include "nautilus-string.h"
 #include "prefs.h"
 #include "translator.h"
@@ -98,12 +101,25 @@ static void gtranslator_learn_buffer_learn_function(gpointer date,
 
 static void gtranslator_learn_buffer_set_umtf_date(void);
 
+/*
+ * Export the hash entries/translation + original msgid pair(s) to a given po
+ *  po file -- uses plain (FILE *) functions -- it's easier to implement.
+ */
+static void gtranslator_learn_buffer_export_hash_entry(gpointer key, 
+	gpointer value, gpointer po_filestream);
+
 /*
  * Escape the characters in the given string to make learning really
  *  work with all characters.
  */
 static gchar *gtranslator_learn_buffer_escape(gchar *str);
 
+/*
+ * Escapes the hash'd strings for the writing in pure po file form -- it's a
+ *  helper function for the learn buffer exporting functions.
+ */
+static gchar *gtranslator_learn_buffer_escape_hash_entry(gchar *hstr);
+
 /*
  * Internal GtrLearnResources list sort routine.
  */
@@ -229,6 +245,51 @@ static void gtranslator_learn_buffer_write_hash_entry(gpointer key, gpointer val
 	GTR_FREE(string_to_write);
 }
 
+/*
+ * Escape some special character cases to allow us a clean and right-formed
+ *  export of the learn buffer's hash entries into the pure/plain po file form.
+ */
+static gchar *gtranslator_learn_buffer_escape_hash_entry(gchar *hstr)
+{
+	gchar	*escaped_str=NULL;
+	
+	g_return_val_if_fail(hstr!=NULL, NULL);
+
+	escaped_str=nautilus_str_replace_substring(hstr, "\"", "\\\"");
+	escaped_str=nautilus_str_replace_substring(escaped_str, "\n", "\\n\n");
+
+	return escaped_str;
+}
+
+/*
+ * Exports a single message/translation pair to the given po file.
+ */
+static void gtranslator_learn_buffer_export_hash_entry(gpointer key, 
+	gpointer value, gpointer po_filestream)
+{
+	gchar *wstr=NULL;
+
+	g_return_if_fail(key!=NULL);
+	g_return_if_fail(value!=NULL);
+	g_return_if_fail(po_filestream!=NULL);
+
+	/*
+	 * Simply escape the hash entries and write them via pure fstream
+	 *  functionality -- not enhanced, but working and easy to do :-)
+	 */
+	wstr=gtranslator_learn_buffer_escape_hash_entry((gchar *) key);
+	g_return_if_fail(wstr!=NULL);
+
+	fprintf(((FILE *) po_filestream), "msgid \"%s\"\n", wstr);
+	GTR_FREE(wstr);
+
+	wstr=gtranslator_learn_buffer_escape_hash_entry((gchar *) value);
+	g_return_if_fail(wstr!=NULL);
+
+	fprintf(((FILE *) po_filestream), "msgstr \"%s\"\n\n", wstr);
+	GTR_FREE(wstr);
+}
+
 /*
  * Set the UMTF serial date for our internal GtrLearnBuffer.
  */
@@ -249,7 +310,7 @@ static void gtranslator_learn_buffer_set_umtf_date()
 	time_struct=localtime(&now);
 
 	/*
-	 * Buold the UMTF alike date string.
+	 * Build the UMTF alike date string.
 	 */
 	strftime(date_string, 20, "%Y-%m-%d %H:%M:%S", time_struct);
 
@@ -689,6 +750,111 @@ void gtranslator_learn_po_file(GtrPo *po_file)
 		gtranslator_learn_buffer->resources);
 }
 
+/*
+ * Export the learn buffer to a gettext po file -- is really not quite perfect
+ *  but fills it's purpose.
+ */
+void gtranslator_learn_export_to_po_file(const gchar *po_file)
+{
+	GList	*resources_list;
+	FILE	*file;
+
+	g_return_if_fail(po_file!=NULL);
+	g_return_if_fail(gtranslator_learn_buffer->init_status==TRUE);
+
+	file=fopen(po_file, "w");
+	g_return_if_fail(file!=NULL);
+
+	/*
+	 * Update/generate the current UMTF style date information.
+	 */
+	gtranslator_learn_buffer_set_umtf_date();
+
+	/*
+	 * Start with an introductory comment at the top of the po file.
+	 */
+	fprintf(file, "# -- This is a po file generated by exporting the learn buffer of gtranslator.\n# ");
+
+	/*
+	 * If the learn buffer features a resources index/list, then we're also
+	 *  exporting it now into the "exported" po file.
+	 */
+	if(gtranslator_learn_buffer->resources)
+	{
+		GtrLearnResource	*resource=NULL;
+		gint			 i=0;
+
+		resources_list=gtranslator_learn_buffer->resources;
+
+		fprintf(file,
+"\n# The exported learn buffer was build on top of these resource po files:");
+
+		while(resources_list!=NULL)
+		{
+			resource=GTR_LEARN_RESOURCE(resources_list->data);
+			i++;
+	
+			if(resource->package)
+			{
+
+				/*
+				 * Write a more or less sophisticated output
+				 *  into the header comment depending on which
+				 *   information is available from the learn
+				 *    buffer.
+				 */
+				if(resource->updated)
+				{
+					fprintf(file,
+					"\n# %i. %s (dated from \"%s\").", 
+					i, resource->package, 
+					resource->updated);
+				}
+				else
+				{
+					fprintf(file,
+					"\n# %i. %s.", i, resource->package);
+				}
+			}
+
+			GTR_ITER(resources_list);
+		}
+	}
+
+	/*
+	 * "Export" a general po file header with values from the translator &
+	 *   the learn buffer/language settings of the user.
+	 */
+	fprintf(file, 
+"\n\"Project-Id-Version: gtranslator-learn-buffer %i\\n\"\n"
+"\"POT-Creation-Date: %s\\n\"\n"
+"\"PO-Revision-Date: %s\\n\"\n"
+"\"Last-Translator: %s <%s>\\n\"\n"
+"\"Language-Team: %s <%s>\\n\"\n"
+"\"MIME-Version: 1.0\\n\"\n"
+"\"Content-Type: text/plain; charset=%s\\n\"\n"
+"\"Content-Transfer-Encoding: 8bit\\n\"\n"
+"\n",
+	gtranslator_learn_buffer->serial,
+	gtranslator_learn_buffer->serial_date,
+	gtranslator_learn_buffer->serial_date,
+	gtranslator_translator->name, 
+	gtranslator_translator->email,
+	gtranslator_translator->language->name,
+	gtranslator_translator->language->group_email,
+	gtranslator_translator->language->encoding);
+
+	/*
+	 * Now we do call our own export function which tries to export every
+	 *  learn buffer entry into the plain (FILE *) file stream.
+	 */
+	g_hash_table_foreach(gtranslator_learn_buffer->hash,
+		(GHFunc) gtranslator_learn_buffer_export_hash_entry, 
+			(gpointer) file);
+
+	fclose(file);
+}
+
 /*
  * Add it to our learned list!
  */
@@ -792,3 +958,61 @@ gchar *gtranslator_learn_get_learned_string(const gchar *search_string)
 		return NULL;
 	}
 }
+
+/*
+ * Translate the given GtrMsg if possible.
+ */
+void gtranslator_learn_translate(gpointer gtr_msg_gpointer)
+{
+	GtrMsg *msg=GTR_MSG(gtr_msg_gpointer);
+
+	if(msg && msg->msgid && !msg->msgstr)
+	{
+		gchar	*result;
+		
+		result=gtranslator_learn_get_learned_string(msg->msgid);
+		
+		if(result)
+		{
+			/*
+			 * Set the translation content, status etc. from the learn buffer.
+			 */
+			msg->msgstr=g_strdup(result);
+			msg->status |= GTR_MSG_STATUS_TRANSLATED;
+			po->file_changed=TRUE;
+			
+			GTR_FREE(result);
+		}
+	}
+}
+
+/*
+ * Autotranslate the opened po file.
+ */
+void gtranslator_learn_autotranslate(gboolean visual_interface)
+{
+	g_return_if_fail(po!=NULL);
+	g_return_if_fail(po->messages!=NULL);
+	
+	g_list_foreach(po->messages, (GFunc) gtranslator_learn_translate,
+		NULL);
+
+	/*
+	 * Activate the Save menu/toolbar items on changes only if there's
+	 *  a GUI already up/wanted at all.
+	 */
+	if(po->file_changed && visual_interface)
+	{
+		gtranslator_actions_enable(ACT_SAVE);
+		
+		gtranslator_messages_table_clear();
+		gtranslator_messages_table_create();
+
+		gtranslator_get_translated_count();
+	}
+	
+	if(visual_interface)
+	{
+		gtranslator_message_show(po->current->data);
+	}
+}
