@@ -29,9 +29,9 @@ extern GnomeUIInfo the_menus[];
 extern GnomeUIInfo the_file_menu[];
 extern GnomeUIInfo the_last_files_menus[];
 extern GnomeUIInfo the_edit_menu[];
-extern GnomeUIInfo the_views_menu[];
 extern GnomeUIInfo the_messages_menu[];
 extern GnomeUIInfo the_msg_status_menu[];
+extern GnomeUIInfo the_colorschemes_menu[];
 extern GnomeUIInfo the_settings_menu[];
 extern GnomeUIInfo the_help_menu[];
 
