@@ -23,6 +23,7 @@
 
 #include "actions.h"
 #include "comment.h"
+#include "formats.h"
 #include "gtkspell.h"
 #include "gui.h"
 #include "learn.h"
@@ -131,9 +132,8 @@ void gtranslator_message_go_to_next_untranslated(GtkWidget * widget, gpointer us
 /* 
  * Display the message in text boxes
  */
-void gtranslator_message_show(GList * list_item)
+void gtranslator_message_show(GtrMsg *msg)
 {
-	GtrMsg *msg;
 	gchar *ispell_command[5];
 
 	if(!file_opened)
@@ -141,9 +141,8 @@ void gtranslator_message_show(GList * list_item)
 		return;
 	}
 	
-	g_return_if_fail(list_item!=NULL);
+	g_return_if_fail(msg!=NULL);
 
-	msg = GTR_MSG(list_item->data);
 	nothing_changes = TRUE;
 	gtranslator_text_boxes_clean();
 
@@ -167,7 +166,7 @@ void gtranslator_message_show(GList * list_item)
 		temp = g_strdup(msg->msgid);
 		gtranslator_utils_invert_dot(temp);
 		
-		gtranslator_syntax_insert_text(text_box, temp);
+		gtranslator_insert_text(GTK_TEXT(text_box), temp);
 		
 		GTR_FREE(temp);
 
@@ -183,22 +182,23 @@ void gtranslator_message_show(GList * list_item)
 			
 			gtranslator_utils_invert_dot(temp);
 			
-			gtranslator_syntax_insert_text(trans_box, temp);
+			gtranslator_insert_text(GTK_TEXT(trans_box), temp);
 			
 			GTR_FREE(temp);
 		}
 	} else {
-		gtranslator_syntax_insert_text(text_box, msg->msgid);
+		gtranslator_insert_text(GTK_TEXT(text_box), msg->msgid);
 
 		if(po->utf8)
 		{
 			gchar *text=gtranslator_utf8_get_plain_msgstr(&msg);
 			
-			gtranslator_syntax_insert_text(trans_box, text);
+			gtranslator_insert_text(GTK_TEXT(trans_box), text);
+
 		}
 		else
 		{
-			gtranslator_syntax_insert_text(trans_box, msg->msgstr);
+			gtranslator_insert_text(GTK_TEXT(trans_box), msg->msgstr);
 		}
 	}
 	
@@ -246,7 +246,6 @@ void gtranslator_message_show(GList * list_item)
 		msg->status & flag);
 	set_active(0, GTR_MSG_STATUS_TRANSLATED);
 	set_active(1, GTR_MSG_STATUS_FUZZY);
-	set_active(2, GTR_MSG_STATUS_STICK);
 #undef set_active
 	nothing_changes = FALSE;
 	message_changed = FALSE;
@@ -311,6 +310,18 @@ void gtranslator_message_update(void)
 		po->translated--;
 	}
 	
+	/*
+	 * Check the formats of the now updated GtrMsg -- simply beep in case
+	 *  of an error for now...
+	 */
+	if(GtrPreferences.check_formats)
+	{
+		if(!gtranslator_formats_check(msg))
+		{
+			printf("\007");
+		}
+	}
+
 	message_changed = FALSE;
 	
 	/*
@@ -346,11 +357,6 @@ void gtranslator_message_change_status(GtkWidget  * item, gpointer which)
 	if (flag == GTR_MSG_STATUS_FUZZY) {
 		gtranslator_message_status_set_fuzzy(GTR_MSG(po->current->data),
 			       GTK_CHECK_MENU_ITEM(item)->active);
-	} else if (flag == GTR_MSG_STATUS_STICK) {
-		gtranslator_message_status_set_sticky(GTR_MSG(po->current->data),
-				GTK_CHECK_MENU_ITEM(item)->active);
-		gtranslator_message_show(po->current);
-		message_changed = TRUE;
 	}
 	
 	gtranslator_message_update();
@@ -381,7 +387,7 @@ void gtranslator_message_go_to(GList * to_go)
 	}
 	
 	po->current = to_go;
-	gtranslator_message_show(po->current);
+	gtranslator_message_show(po->current->data);
 
 	if(GtrPreferences.show_messages_table)
 	{
@@ -450,7 +456,7 @@ void gtranslator_message_status_set_fuzzy(GtrMsg * msg, gboolean fuzzy)
 	g_return_if_fail(msg->comment!=NULL);
 	g_return_if_fail(GTR_COMMENT(msg->comment)->comment!=NULL);
 
-	comment=GTR_COMMENT(msg->comment)->comment;
+	comment=gtranslator_comment_get_comment_contents(msg->comment);
 	
 	if (!compiled) {
 		regcomp(&rexf, "^(#), c-format", REG_EXTENDED | REG_NEWLINE);
@@ -479,7 +485,11 @@ void gtranslator_message_status_set_fuzzy(GtrMsg * msg, gboolean fuzzy)
 
 		gtranslator_comment_update(&msg->comment, comchar);
 		
-		GTR_FREE(comment);
+		/*
+		 * FIXME: Crashes currently...
+		 *
+		 * GTR_FREE(comment);
+		 */
 		GTR_FREE(comchar);
 	} else {
 		msg->status &= ~GTR_MSG_STATUS_FUZZY;
@@ -494,23 +504,27 @@ void gtranslator_message_status_set_fuzzy(GtrMsg * msg, gboolean fuzzy)
 /*
  * Set Sticky status.
  */
-void gtranslator_message_status_set_sticky (GtrMsg * msg, gboolean on)
+void gtranslator_message_status_set_sticky (GtrMsg * msg, gpointer useless)
 {
-	if (on) {
-		GTR_FREE(msg->msgstr);
-		msg->msgstr = g_strdup(msg->msgid);
-		
-		/*
-		 * It is no longer fuzzy
-		 */
-		gtranslator_message_status_set_fuzzy(msg, FALSE);
-		msg->status |= GTR_MSG_STATUS_STICK;
-	} else {
-		GTR_FREE(msg->msgstr);
-		msg->msgstr = g_strdup("");
-		msg->status &= ~GTR_MSG_STATUS_STICK;
-	}
+	g_return_if_fail(file_opened==TRUE);
+
+	msg=GTR_MSG(GTR_PO(po)->current->data);
+	g_return_if_fail(msg!=NULL);
+
+	GTR_FREE(msg->msgstr);
+	msg->msgstr = g_strdup(msg->msgid);
+	
+	/*
+	 * It is no longer fuzzy.
+	 */
+	gtranslator_message_status_set_fuzzy(msg, FALSE);
+	msg->status |= GTR_MSG_STATUS_STICK;
+	msg->status |= GTR_MSG_STATUS_TRANSLATED;
+
+	message_changed = TRUE;
+	gtranslator_message_show(po->current->data);
 	gtranslator_get_translated_count();
+	gtranslator_actions_enable(ACT_REVERT, ACT_SAVE);
 }
 
 /*
