@@ -43,7 +43,6 @@
 #include "prefs.h"
 #include "runtime-config.h"
 #include "save.h"
-#include "sidebar.h"
 #include "translator.h"
 #include "undo.h"
 #include "utf8.h"
@@ -362,6 +361,19 @@ gboolean gtranslator_parse_core(void)
 				{
 					append_line(&msg->msgstr, line);
 				}
+				else if((comment_ok == FALSE) &&
+					(msgid_ok == FALSE) &&
+					(msgstr_ok == FALSE))
+				{
+					/*
+					 * This might seem to be a nonsense
+					 *  issue/check, but it occurs if a
+					 *   multiple line message features an
+					 *    empty line before the msgstr
+					 *     content parts (b.g.o #68782).
+					 */
+					continue;
+				}
 				else
 				{
 					g_assert_not_reached();
@@ -451,10 +463,8 @@ void gtranslator_parse_main(const gchar *filename)
 	}
 	else
 	{
-		gtranslator_config_init();
 		gtranslator_config_set_string("runtime/filename", 
 			(gchar *) filename);
-		gtranslator_config_close();
 	}
 
 	/*
@@ -550,7 +560,7 @@ void gtranslator_parse_main(const gchar *filename)
 		gtranslator_header_edit_dialog(NULL, NULL);
 	}
 	
-	gtranslator_message_show(po->current);
+	gtranslator_message_show(po->current->data);
 
 	/*
 	 * Test if the filename is NOT equivalent to our temp files' names.
@@ -576,11 +586,6 @@ void gtranslator_parse_main(const gchar *filename)
 	 */
 	gtranslator_history_show();
 
-	/*
-	 * Add the view for the current file.
-	 */ 
-	gtranslator_sidebar_activate_views();
-
 	/*
 	 * Create and set the messages table/tree up.
 	 */
@@ -888,26 +893,7 @@ void gtranslator_save_file_dialog(GtkWidget * widget, gpointer sfa_dlg)
 void gtranslator_save_current_file_dialog(GtkWidget * widget, gpointer useless)
 {
 	if (!po->file_changed) {
-		if (GtrPreferences.dont_save_unchanged_files)
-			return;
-		if (GtrPreferences.warn_if_no_change) {
-			GtkWidget *dialog;
-			gchar *question;
-			gint reply;
-			question = g_strdup_printf(_("You didn't change anything in\n%s\nDo you want to save it anyway?"),
-					    po->filename);
-			dialog = gnome_message_box_new(question,
-			    GNOME_MESSAGE_BOX_QUESTION,
-			    GNOME_STOCK_BUTTON_YES,
-			    GNOME_STOCK_BUTTON_NO,
-			    GNOME_STOCK_BUTTON_CANCEL,
-			    NULL);
-			gtranslator_dialog_show(&dialog, _("gtranslator -- unchanged"));
-			reply = gnome_dialog_run(GNOME_DIALOG(dialog));
-			GTR_FREE(question);
-			if (reply != GNOME_YES)
-				return;
-		}
+		return;
 	}
 
 	gtranslator_save_file(po->filename);
@@ -931,15 +917,10 @@ void gtranslator_po_free(void)
 		gtranslator_header_free(po->header);
 	}
 	
-	if(po->locale_charset)
-	{
-		GTR_FREE(po->locale_charset);
-	}
-	
+	GTR_FREE(po->locale_charset);
 	GTR_FREE(po->filename);
 	GTR_FREE(po->obsolete);
 	GTR_FREE(po);
-	po = NULL;
 }
 
 void gtranslator_file_close(GtkWidget * widget, gpointer useless)
@@ -954,7 +935,6 @@ void gtranslator_file_close(GtkWidget * widget, gpointer useless)
 	
 	gtranslator_po_free();
 	gtranslator_undo_clean_register();
-	gtranslator_sidebar_clear_views();
 	
 	file_opened = FALSE;
 	nothing_changes = TRUE;
@@ -998,9 +978,7 @@ void gtranslator_file_close(GtkWidget * widget, gpointer useless)
 	/*
 	 * "Remove" the stored "runtime/filename" key.
 	 */
-	gtranslator_config_init();
 	gtranslator_config_set_string("runtime/filename", "--- No file ---");
-	gtranslator_config_close();
 
 	nothing_changes = FALSE;
 }
