@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
@@ -31,8 +31,6 @@
 #include "messages-table.h"
 #include "nautilus-string.h"
 #include "prefs.h"
-#include "query.h"
-#include "sidebar.h"
 #include "stylistics.h"
 #include "translator.h"
 #include "utils.h"
@@ -48,6 +46,7 @@ static void gtranslator_preferences_dialog_changed(GtkWidget  * widget, gpointer
 static void gtranslator_preferences_dialog_apply(GtkWidget  * widget, gint page_num,
 			    gpointer useless);
 static void gtranslator_preferences_dialog_help(GtkWidget  * widget, gpointer useless);
+static void toggle_sensitive(GtkWidget *widget, gpointer data);
 
 /*
  * The notebook page widgets: 
@@ -69,15 +68,14 @@ static GtkWidget
  * The toggle buttons used in the preferences box:
  */
 static GtkWidget
-	*warn_if_no_change, *warn_if_fuzzy, *unmark_fuzzy,
-	*dont_save_unchanged_files, *save_geometry_tb, *show_sidebar,
+	*warn_if_fuzzy, *unmark_fuzzy, *save_geometry_tb,
 	*enable_popup_menu, *use_dot_char, *use_update_function,
 	*check_recent_files, *own_fonts, *own_colors, *use_own_dict,
-	*instant_spell_checking, *keep_obsolete, *defaultdomain,
-	*autosave, *autosave_with_suffix, *sweep_compile_file,
-	*use_learn_buffer, *show_messages_table, *rambo_function,
-	*use_own_mt_colors, *collapse_translated_entries, *auto_learn,
-	*fuzzy_matching, *load_backends, *show_comment;
+	*instant_spell_checking, *keep_obsolete, *autosave,
+	*autosave_with_suffix, *sweep_compile_file, *use_learn_buffer,
+	*show_messages_table, *rambo_function, *use_own_mt_colors,
+	*collapse_translated_entries, *auto_learn, *fuzzy_matching,
+	*load_backends, *show_comment, *highlight;
 
 /*
  * The timeout GtkSpinButton:
@@ -103,9 +101,8 @@ static GtkWidget *prefs = NULL;
 
 void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 {
-	GList 	*colorschemeslist=NULL;
 	gchar	*old_colorscheme=NULL;
-	gchar	*personal_schemes_directory=NULL;
+	GtkObject *adjustment;
 	
 	/*
 	 * Create the preferences box... 
@@ -119,7 +116,7 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	 * The tables for holding all the entries below.
 	 */
 	first_page = gtranslator_utils_append_page_to_preferences_dialog(prefs, 
-		3, 2, _("Personal information")); 
+		2, 2, _("Personal information")); 
 	second_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		5, 2, _("Language settings"));
 	third_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
@@ -127,11 +124,11 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	fourth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		9, 1, _("Miscellaneous"));
 	fifth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
-		4, 2, _("Recent files & spell checking"));
+		3, 2, _("Recent files & spell checking"));
 	sixth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		6, 2, _("Fonts, colors and color schemes"));
 	seventh_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
-		4, 2, _("Autosaving"));
+		2, 2, _("Autosaving"));
 	eighth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		6, 2, _("Messages table"));
 	ninth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
@@ -147,21 +144,6 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	    gtranslator_utils_attach_entry_with_label(first_page, 1, _("Author's EMail:"),
 		gtranslator_translator->email, gtranslator_preferences_dialog_changed);
 
-	/*
-	 * If no domainslist could be got from the startup routines, build up a foo'sh list.
-	 */
-	if(!domains)
-	{
-		domains=g_list_prepend(domains, g_strdup(""));
-		domains=g_list_reverse(domains);
-	}
-
-	defaultdomain =
-	    gtranslator_utils_attach_combo_with_label(first_page, 2, _("Default query domain:"),
-			    	    domains, gtranslator_translator->query_domain,
-				    FALSE,
-				    gtranslator_preferences_dialog_changed, NULL);
-	
 	/*
 	 * Create, attach, and connect all the combo boxes with labels. 
 	 */
@@ -204,18 +186,14 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	    gtranslator_utils_attach_toggle_with_label(third_page, 1,
 		_("Warn if the po file contains fuzzy translations"),
 		GtrPreferences.warn_if_fuzzy, gtranslator_preferences_dialog_changed);
-	dont_save_unchanged_files =
-	    gtranslator_utils_attach_toggle_with_label(third_page, 2,
-		_("Don't save unchanged po files"),
-		GtrPreferences.dont_save_unchanged_files, gtranslator_preferences_dialog_changed);
-	warn_if_no_change =
-	    gtranslator_utils_attach_toggle_with_label(third_page, 3,
-		_("Warn me if I'm trying to save an unchanged file"),
-		GtrPreferences.warn_if_no_change, gtranslator_preferences_dialog_changed);
 	keep_obsolete =
-	    gtranslator_utils_attach_toggle_with_label(third_page, 4,
-		_("Keep obsolete message in the po files"),
+	    gtranslator_utils_attach_toggle_with_label(third_page, 2,
+		_("Keep obsolete messages in the po files"),
 		GtrPreferences.keep_obsolete, gtranslator_preferences_dialog_changed);
+	highlight =
+	    gtranslator_utils_attach_toggle_with_label(third_page, 3,
+	    	_("Highlight syntax of the translation messages"),
+		GtrPreferences.highlight, gtranslator_preferences_dialog_changed);
 
 	/*
 	 * The fourth page with the popup menu & the dot_char.
@@ -244,9 +222,6 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	show_comment=gtranslator_utils_attach_toggle_with_label(fourth_page,
 		8, _("Show instant comment view in the main pane"),
 		GtrPreferences.show_comment, gtranslator_preferences_dialog_changed);
-	show_sidebar=gtranslator_utils_attach_toggle_with_label(fourth_page,
-		9, _("Show the views sidebar"),
-		GtrPreferences.show_sidebar, gtranslator_preferences_dialog_changed);
 	
 	/*
 	 * The fifth page with the Recent files options.
@@ -261,55 +236,30 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	instant_spell_checking=gtranslator_utils_attach_toggle_with_label(fifth_page, 2,
 		_("Instant spell checking"),
 		GtrPreferences.instant_spell_check, gtranslator_preferences_dialog_changed);
-	use_own_dict=gtranslator_utils_attach_toggle_with_label(fifth_page, 3,
-		_("Use special dictionary"),
-		GtrPreferences.use_own_dict, gtranslator_preferences_dialog_changed);
-	dictionary_file=
-	    gtranslator_utils_attach_entry_with_label(fifth_page, 4, 
-	    	_("Dictionary to use:"),
-	        GtrPreferences.dictionary, gtranslator_preferences_dialog_changed);
+	
+	use_own_dict = gtk_check_button_new_with_label(_("Use special dictionary:"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(use_own_dict),
+	                             GtrPreferences.use_own_dict);
+	gtk_table_attach_defaults(GTK_TABLE(fifth_page), use_own_dict, 0, 1, 3, 4);
+	
+	dictionary_file = gtk_entry_new();
+	if (GtrPreferences.dictionary)
+		gtk_entry_set_text(GTK_ENTRY(dictionary_file), GtrPreferences.dictionary);
+	gtk_widget_set_sensitive(GTK_WIDGET(dictionary_file), GtrPreferences.use_own_dict);
+	gtk_table_attach_defaults(GTK_TABLE(fifth_page), dictionary_file, 1, 2, 3, 4);
+	
+	gtk_signal_connect(GTK_OBJECT(use_own_dict), "toggled",
+			   GTK_SIGNAL_FUNC(toggle_sensitive), dictionary_file);
+	gtk_signal_connect(GTK_OBJECT(dictionary_file), "changed",
+			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_changed), NULL);
 	
 	/*
 	 * The sixth page with the special font/color stuff.
 	 */
-	personal_schemes_directory=g_strdup_printf("%s/.gtranslator/colorschemes",
-		g_get_home_dir());
-
-	/*
-	 * First load all colorschemes from ~/.gtranslator/colorschemes.
-	 */
-	colorschemeslist=gtranslator_utils_file_names_from_directory(personal_schemes_directory,
-		".xml", TRUE, TRUE, FALSE);
-	GTR_FREE(personal_schemes_directory);
-
-	/*
-	 * Now append/set up the colorschemes from the global colorschemes
-	 *  reservoire.
-	 */
-	if(!colorschemeslist)
-	{
-		colorschemeslist=gtranslator_utils_file_names_from_directory(SCHEMESDIR,
-			".xml", TRUE, TRUE, FALSE);
-	}
-	else
-	{
-		GList	*global_colorschemes=NULL;
-
-		global_colorschemes=gtranslator_utils_file_names_from_directory(SCHEMESDIR,
-			".xml", TRUE, TRUE, FALSE);
-
-		/*
-		 * Append and resort the colorschemes list (now consisting of global +
-		 *  personal colorschemes directory contents).
-		 */
-		colorschemeslist=g_list_concat(colorschemeslist, global_colorschemes);
-		colorschemeslist=g_list_sort(colorschemeslist, (GCompareFunc) nautilus_strcmp);
-	}
-	
 	old_colorscheme=gtranslator_utils_get_raw_file_name(GtrPreferences.scheme);
 	
 	scheme_file=gtranslator_utils_attach_combo_with_label(sixth_page, 0,
-		_("Syntax color scheme to use:"), colorschemeslist, old_colorscheme,
+		_("Syntax color scheme to use:"), colorschemes, old_colorscheme,
 		FALSE,
 		gtranslator_preferences_dialog_changed, NULL);
 	 
@@ -340,21 +290,36 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	/*
 	 * The seventh page of the prefs-box: autosaving options.
 	 */
-	autosave=gtranslator_utils_attach_toggle_with_label(seventh_page, 0,
-		_("Save po files automatically at regular intervals"),
-		GtrPreferences.autosave, gtranslator_preferences_dialog_changed);
-	
-	autosave_with_suffix=gtranslator_utils_attach_toggle_with_label(seventh_page, 1,
-		_("Append a special suffix to the automatically saved files"),
-		GtrPreferences.autosave_with_suffix, gtranslator_preferences_dialog_changed);
-	
-	autosave_suffix=gtranslator_utils_attach_entry_with_label(seventh_page, 2,
-		_("Autosave suffix:"),
-		GtrPreferences.autosave_suffix, gtranslator_preferences_dialog_changed);
+	autosave = gtk_check_button_new_with_label(_("Automatically save po files at regular intervals (in minutes):"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(autosave),
+	                             GtrPreferences.autosave);
+	gtk_table_attach_defaults(GTK_TABLE(seventh_page), autosave, 0, 1, 0, 1);
 
-	autosave_timeout=gtranslator_utils_attach_spin_with_label(seventh_page, 3,
-		_("Autosave timeout in minutes:"), 1.0, 30.0,
-		GtrPreferences.autosave_timeout, gtranslator_preferences_dialog_changed);
+	adjustment=gtk_adjustment_new(GtrPreferences.autosave_timeout, 1.0, 30.0, 1.0, 1.0, 1.0);	
+	autosave_timeout=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment), 1, 0);
+	gtk_widget_set_sensitive(GTK_WIDGET(autosave_timeout), GtrPreferences.autosave);
+	gtk_table_attach_defaults(GTK_TABLE(seventh_page), autosave_timeout, 1, 2, 0, 1);
+	
+	gtk_signal_connect(GTK_OBJECT(autosave), "toggled",
+			   GTK_SIGNAL_FUNC(toggle_sensitive), autosave_timeout);
+	gtk_signal_connect(GTK_OBJECT(autosave_timeout), "changed",
+			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_changed), NULL);
+
+	autosave_with_suffix = gtk_check_button_new_with_label(_("Append a suffix to automatically saved files:"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(autosave_with_suffix),
+	                             GtrPreferences.autosave_with_suffix);
+	gtk_table_attach_defaults(GTK_TABLE(seventh_page), autosave_with_suffix, 0, 1, 1, 2);
+
+	autosave_suffix = gtk_entry_new();
+	if (GtrPreferences.autosave_suffix)
+		gtk_entry_set_text(GTK_ENTRY(autosave_suffix), GtrPreferences.autosave_suffix);
+	gtk_widget_set_sensitive(GTK_WIDGET(autosave_suffix), GtrPreferences.autosave_with_suffix);
+	gtk_table_attach_defaults(GTK_TABLE(seventh_page), autosave_suffix, 1, 2, 1, 2);
+	
+	gtk_signal_connect(GTK_OBJECT(autosave_with_suffix), "toggled",
+			   GTK_SIGNAL_FUNC(toggle_sensitive), autosave_suffix);
+	gtk_signal_connect(GTK_OBJECT(autosave_suffix), "changed",
+			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_changed), NULL);
 
 	/*
 	 * The eighth page with the messages table concerning settings.
@@ -496,7 +461,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	update(gtranslator_translator->language->group_email, GTK_COMBO(lg_email)->entry);
 	update(gtranslator_translator->language->encoding, GTK_COMBO(mime_type)->entry);
 	update(gtranslator_translator->language->bits, GTK_COMBO(encoding)->entry);
-	update(gtranslator_translator->query_domain, GTK_COMBO(defaultdomain)->entry);
 	update(GtrPreferences.dictionary, dictionary_file);
 	update(GtrPreferences.autosave_suffix, autosave_suffix);
 #undef update
@@ -505,15 +469,14 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	GtrPreferences.save_geometry = if_active(save_geometry_tb);
 	GtrPreferences.unmark_fuzzy = if_active(unmark_fuzzy);
 	GtrPreferences.warn_if_fuzzy = if_active(warn_if_fuzzy);
-	GtrPreferences.warn_if_no_change = if_active(warn_if_no_change);
-	GtrPreferences.dont_save_unchanged_files = if_active(dont_save_unchanged_files);
+	GtrPreferences.highlight = if_active(highlight);
 	GtrPreferences.dot_char = if_active(use_dot_char);
 	GtrPreferences.update_function = if_active(use_update_function);
 	GtrPreferences.rambo_function = if_active(rambo_function);
 	GtrPreferences.popup_menu = if_active(enable_popup_menu);
 	GtrPreferences.sweep_compile_file = if_active(sweep_compile_file);
-	GtrPreferences.show_sidebar = if_active(show_sidebar);
 	GtrPreferences.show_comment = if_active(show_comment);
+	GtrPreferences.show_messages_table = if_active(show_messages_table);
 	GtrPreferences.collapse_translated = if_active(collapse_translated_entries);
 	GtrPreferences.check_recent_file = if_active(check_recent_files);
 	GtrPreferences.instant_spell_check = if_active(instant_spell_checking);
@@ -530,26 +493,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	GtrPreferences.autosave_with_suffix = if_active(autosave_with_suffix);
 #undef if_active
 
-	gtranslator_config_init();
-	
-	/*
-	 * Write the messages table setting directly -- so we do always respect
-	 *  changes on a restart.
-	 */
-	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(show_messages_table)))
-	{
-		gtranslator_config_set_bool("toggles/show_messages_table", 
-			TRUE);
-	}
-	else
-	{
-		gtranslator_config_set_bool("toggles/show_messages_table",
-			FALSE);
-	}
-	
-	/*
-	 * Read out the SpinButton's.
-	 */
 	GtrPreferences.autosave_timeout = 
 		gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(
 			autosave_timeout));
@@ -665,10 +608,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	gtranslator_config_set_bool("toggles/warn_if_fuzzy", GtrPreferences.warn_if_fuzzy);
 	gtranslator_config_set_bool("toggles/set_non_fuzzy_if_changed", 
 			      GtrPreferences.unmark_fuzzy);
-	gtranslator_config_set_bool("toggles/warn_if_no_change",
-			      GtrPreferences.warn_if_no_change);
-	gtranslator_config_set_bool("toggles/do_not_save_unchanged_files",
-			      GtrPreferences.dont_save_unchanged_files);
 	gtranslator_config_set_bool("toggles/use_dot_char",
 			      GtrPreferences.dot_char);
 	gtranslator_config_set_bool("toggles/use_update_function",
@@ -677,14 +616,16 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			      GtrPreferences.sweep_compile_file);
 	gtranslator_config_set_bool("toggles/enable_popup_menu",
 			      GtrPreferences.popup_menu);
-	gtranslator_config_set_bool("toggles/show_sidebar",
-			      GtrPreferences.show_sidebar);
 	gtranslator_config_set_bool("toggles/show_comment",
 			      GtrPreferences.show_comment);
 	gtranslator_config_set_bool("toggles/rambo_function",
 			      GtrPreferences.rambo_function);
 	gtranslator_config_set_bool("toggles/check_recent_files",
 			      GtrPreferences.check_recent_file);
+	gtranslator_config_set_bool("toggles/check_formats",
+			      GtrPreferences.check_formats);
+	gtranslator_config_set_bool("toggles/highlight",
+			      GtrPreferences.highlight);
 	gtranslator_config_set_bool("toggles/instant_spell_check",
 			      GtrPreferences.instant_spell_check);
 	gtranslator_config_set_bool("toggles/use_own_fonts",
@@ -703,6 +644,8 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			      GtrPreferences.load_backends);
 	gtranslator_config_set_bool("toggles/auto_learn",
 			      GtrPreferences.auto_learn);
+	gtranslator_config_set_bool("toggles/show_messages_table",
+			      GtrPreferences.show_messages_table);
 	gtranslator_config_set_bool("toggles/collapse_translated_entries",
 			      GtrPreferences.collapse_translated);
 	gtranslator_config_set_bool("toggles/keep_obsolete",
@@ -712,26 +655,11 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	gtranslator_config_set_bool("toggles/autosave_with_suffix",
 			      GtrPreferences.autosave_with_suffix);
 
-	gtranslator_config_close();
-
 	/*
 	 * Save our translator data.
 	 */
 	gtranslator_translator_save(gtranslator_translator);
 
-	/*
-	 * Show or hide the sidebar according to the _possibly_ changed
-	 *  setting in the preferences dialog.
-	 */
-	if(GtrPreferences.show_sidebar)
-	{
-		gtranslator_sidebar_show();
-	}
-	else
-	{
-		gtranslator_sidebar_hide();
-	}
-
 	/*
 	 * Hide the comment viewing (area) via our new util function.
 	 */
@@ -794,6 +722,14 @@ static void gtranslator_preferences_dialog_changed(GtkWidget  * widget, gpointer
 #undef set_text
 }
 
+void toggle_sensitive(GtkWidget *widget, gpointer data)
+{
+	gboolean active;
+	active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+	gtk_widget_set_sensitive(GTK_WIDGET(data), active);
+	gnome_property_box_changed(GNOME_PROPERTY_BOX(prefs));
+}
+
 void gtranslator_preferences_read(void)
 {
 	/*
@@ -802,8 +738,6 @@ void gtranslator_preferences_read(void)
 	 */  
 	gtranslator_preferences_init_default_values();
 
-	gtranslator_config_init();
-	
 	GtrPreferences.msgid_font = 
 		gtranslator_config_get_string("interface/original_font");
 	GtrPreferences.msgstr_font = 
@@ -852,10 +786,6 @@ void gtranslator_preferences_read(void)
 		gtranslator_config_get_bool("toggles/set_non_fuzzy_if_changed"); 
 	GtrPreferences.warn_if_fuzzy =
 		gtranslator_config_get_bool("toggles/warn_if_fuzzy");
-	GtrPreferences.warn_if_no_change =
-		gtranslator_config_get_bool("toggles/warn_if_no_change");
-	GtrPreferences.dont_save_unchanged_files =
-		gtranslator_config_get_bool("toggles/do_not_save_unchanged_files");
 	GtrPreferences.popup_menu =
 		gtranslator_config_get_bool("toggles/enable_popup_menu");
 	GtrPreferences.update_function =
@@ -887,6 +817,10 @@ void gtranslator_preferences_read(void)
 		"toggles/load_backends");
 	GtrPreferences.auto_learn = gtranslator_config_get_bool(
 		"toggles/auto_learn");
+	GtrPreferences.check_formats = gtranslator_config_get_bool(
+		"toggles/check_formats");
+	GtrPreferences.highlight = gtranslator_config_get_bool(
+		"toggles/highlight");
 	GtrPreferences.match_case = gtranslator_config_get_bool(
 		"find/case_sensitive");
 	GtrPreferences.find_in = gtranslator_config_get_int("find/find_in");
@@ -894,8 +828,6 @@ void gtranslator_preferences_read(void)
 	
 	GtrPreferences.fill_header = gtranslator_config_get_bool(
 		"toggles/fill_header");
-	GtrPreferences.show_sidebar = gtranslator_config_get_bool(
-		"toggles/show_sidebar");
 	GtrPreferences.show_comment = gtranslator_config_get_bool(
 		"toggles/show_comment");
 	GtrPreferences.show_messages_table = gtranslator_config_get_bool(
@@ -914,8 +846,6 @@ void gtranslator_preferences_read(void)
 		gtranslator_set_style(text_box, 0);
 		gtranslator_set_style(trans_box, 1);
 	}
-
-	gtranslator_config_close();
 }
 
 /*
