@@ -247,7 +247,6 @@ void gtranslator_utils_set_language_values_by_language(const gchar *language)
 		if(!nautilus_strcasecmp(languages[i].name, language) ||
 			!nautilus_strcasecmp(_(languages[i].name), language))
 		{
-			gtranslator_config_init();
 			gtranslator_config_set_string("language/name", languages[i].name);
 			gtranslator_config_set_string("language/language_code", languages[i].locale);
 			
@@ -263,7 +262,6 @@ void gtranslator_utils_set_language_values_by_language(const gchar *language)
 			
 			gtranslator_config_set_string("language/mime_type", languages[i].encoding);
 			gtranslator_config_set_string("language/encoding", languages[i].bits);
-			gtranslator_config_close();
 
 			return;
 		}
@@ -481,6 +479,48 @@ gchar *gtranslator_utils_get_environment_locale()
 	return localename;
 }
 
+/*
+ * Returns the "official" charset name for the currently active environment
+ *  locale.
+ */
+gchar *gtranslator_utils_get_environment_charset()
+{
+	gchar	*locale_name=NULL;
+	gchar	*locale_charset=NULL;
+
+	locale_name=gtranslator_utils_get_environment_locale();
+
+	if(!locale_name)
+	{
+		/*
+		 * Translators: this should be your default fall back encoding
+		 *  which will be used if gtranslator can't get the current env. locale's
+		 *   default sane encoding by itself.
+		 */
+		locale_charset=g_strdup(_("iso-8859-1"));
+	}
+	else if(!nautilus_strcasecmp(locale_name, "C") || !nautilus_strcasecmp(locale_name, "POSIX"))
+	{
+		locale_charset=g_strdup(_("iso-8859-1"));
+	}
+	else
+	{
+		gint c;
+
+		for(c=0; languages[c].name!=NULL; c++)
+		{
+			if(!nautilus_strcasecmp(languages[c].locale, locale_name))
+			{
+				locale_charset=g_strdup(languages[c].encoding);
+			}
+		}
+
+		GTR_FREE(locale_name);
+	}
+
+	return locale_charset;
+}
+
 /*
  * Subsequently filter out all extension containing filename from the directory.
  * 
@@ -609,10 +649,20 @@ gfloat gtranslator_utils_calculate_similarity(const gchar *a, const gchar *b)
 	 */
 	if(strlen(a) > strlen(b))
 	{
+		if(!g_strncasecmp(a, b, (strlen(a) - 1)))
+		{
+			return 100.0;
+		}
+
 		one_char_percentage=(100 / (strlen(a) - 1));
 	}
 	else
 	{
+		if(!g_strncasecmp(b, a, (strlen(b) - 1)))
+		{
+			return 100.0;
+		}
+
 		one_char_percentage=(100 / (strlen(b) - 1));
 	}
 
@@ -622,11 +672,15 @@ gfloat gtranslator_utils_calculate_similarity(const gchar *a, const gchar *b)
 	 */
 	while(a[i] && b[i] && a[i]!='\0' && b[i]!='\0')
 	{
-		if(a[i]==b[i])
+		if((a[i] <= 32) || (b[i] <= 32))
+		{
+			continue;
+		}
+		else if(a[i]==b[i])
 		{
 			similarity+=one_char_percentage;
 		}
-		else if(tolower(a[i])==tolower(b[i]))
+		else if((tolower(a[i]))==(tolower(b[i])))
 		{
 			similarity+=(one_char_percentage / 2);
 		}
@@ -634,7 +688,14 @@ gfloat gtranslator_utils_calculate_similarity(const gchar *a, const gchar *b)
 		i++;
 	}
 
-	return similarity;
+	if(similarity >= 100.0)
+	{
+		return 100.0;
+	}
+	else
+	{
+		return similarity;
+	}
 }
 
 /*
@@ -689,7 +750,7 @@ gchar *gtranslator_utils_get_locale_name(void)
 		{
 			/*
 			 * Check for the language in the header -- may it be in 
-			 *  English or in the current locale..
+			 *  English or in the current locale...
 			 */
 			if(!nautilus_strcasecmp(languages[c].name, 
 					po->header->language) ||
@@ -725,11 +786,50 @@ gchar *gtranslator_utils_get_locale_charset(void)
 
 		for(c=0; languages[c].name!=NULL; c++)
 		{
-			if(!nautilus_strcmp(languages[c].name, po->header->language) ||
-				!nautilus_strcmp(_(languages[c].name), po->header->language))
+			if(!nautilus_strcasecmp(languages[c].name, 
+					po->header->language) ||
+				!nautilus_strcasecmp(_(languages[c].name), 
+					po->header->language))
 			{
 				return g_strdup(languages[c].encoding);
 			}
+			else if(strstr(po->header->language, "/"))
+			{
+				/*
+				 * If no direct language name did match and
+				 *  we have a compound (or not compound :-)) 
+				 *   language name, then we need some voodoo.
+				 */
+				gchar	*partial_charset_name=NULL;
+
+				partial_charset_name=nautilus_str_get_after_prefix(languages[c].name, "/");
+			
+				/*
+				 * Always do grep the after-"/"-language name
+				 *  for our voodoo plays (like mentioned in 
+				 *   b.g.o #69720 for "Norwegian/Nynorsk").
+				 */
+				if(!partial_charset_name)
+				{
+					partial_charset_name=nautilus_str_get_after_prefix(_(languages[c].name), "/");
+				}
+
+				/*
+				 * Now test the language names again for a bit
+				 *  more sanity on "compund" language names.
+				 */
+				if(partial_charset_name)
+				{
+					partial_charset_name++;
+
+					if(nautilus_strcasecmp(partial_charset_name, po->header->language))
+					{
+						return g_strdup(languages[c].encoding);
+					}
+
+					GTR_FREE(partial_charset_name);
+				}
+			}
 		}
 
 		return NULL;
@@ -821,8 +921,6 @@ void gtranslator_utils_old_colors_to_new_location()
 	gchar *value;
 	gboolean converted=FALSE;
 	
-	gtranslator_config_init();
-
 	value=gtranslator_config_get_string("colors/fg");
 
 	if(value && value[0]=='#')
@@ -844,8 +942,6 @@ void gtranslator_utils_old_colors_to_new_location()
 		gtranslator_config_set_string("colors/fg", "black");
 		gtranslator_config_set_string("colors/bg", "white");
 	}
-
-	gtranslator_config_close();
 }
 
 /* gtranslator_utils_getline
