@@ -1,5 +1,5 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include "gui.h"
 #include "nautilus-string.h"
 #include "prefs.h"
+#include "runtime-config.h"
 #include "utils.h"
 #include "utils_gui.h"
 
@@ -65,17 +66,8 @@ void gtranslator_utils_invert_dot(gchar *str)
 
 	for(i=0; str[i] != '\0'; i++) {
 		if(str[i]==' ') {
-			/*
-			 * The "" is the "middle dot" (00B7), it is
-			 * used by gtranslator as special char to make
-			 * blanks visible.
-			 * If your language uses that char for another
-			 * purpose or if you use a charset encoding
-			 * that doesn't have it, feel free to change it
-			 * to whatever you think will be better 
-			 */
-			str[i]=(_("\xb7"))[0];
-		} else if(str[i]==(_("\xb7"))[0]) {
+			str[i]=gtranslator_runtime_config->special_char;
+		} else if(str[i]==gtranslator_runtime_config->special_char) {
 			str[i]=' ';
 		}
 	}
@@ -92,12 +84,10 @@ void gtranslator_utils_save_geometry(void)
 		gstr = gnome_geometry_string(gtranslator_application->window);
 		gnome_parse_geometry(gstr, &x, &y, &w, &h);
 		GTR_FREE(gstr);
-		gtranslator_config_init();
 		gtranslator_config_set_int("geometry/x", x);
 		gtranslator_config_set_int("geometry/y", y);
 		gtranslator_config_set_int("geometry/width", w);
 		gtranslator_config_set_int("geometry/height", h);
-		gtranslator_config_close();
 		
 	}
 }
@@ -113,12 +103,10 @@ void gtranslator_utils_restore_geometry(gchar  * gstr)
 	 */
 	if (gstr == NULL) {
 		if (GtrPreferences.save_geometry == TRUE) {
-			gtranslator_config_init();
 			x = gtranslator_config_get_int("geometry/x");
 			y = gtranslator_config_get_int("geometry/y");
 			width = gtranslator_config_get_int("geometry/width");
 			height = gtranslator_config_get_int("geometry/height");
-			gtranslator_config_close();
 		}
 		else return;
 	}
@@ -172,7 +160,9 @@ GtkWidget *gtranslator_utils_attach_toggle_with_label(GtkWidget  * table, gint r
 	GtkWidget *toggle;
 	toggle = gtk_check_button_new_with_label(label_text);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle), value);
-	gtk_table_attach_defaults(GTK_TABLE(table), toggle, 0, 1, row, row + 1);
+	gtk_table_attach_defaults(GTK_TABLE(table), toggle,
+	                          0, GTK_TABLE(table)->ncols > 1 ? 2 : 1,
+	                          row, row + 1);
 
 	if(callback)
 	{
@@ -307,10 +297,8 @@ GtkWidget *gtranslator_utils_attach_color_with_label(GtkWidget *table,
 	gnome_color_picker_set_title(GNOME_COLOR_PICKER(color_selector),
 		title_text);
 	
-	gtranslator_config_init();
 	gtranslator_color_values_get(GNOME_COLOR_PICKER(color_selector), 
 		color_type);
-	gtranslator_config_close();
 	
 	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, row, row + 1);
 	gtk_table_attach_defaults(GTK_TABLE(table), color_selector, 1, 2, 
@@ -398,9 +386,7 @@ gboolean gtranslator_utils_check_file_being_open(const gchar *filename)
 
 	g_return_val_if_fail(filename!=NULL, FALSE);
 
-	gtranslator_config_init();
 	resultfilename=gtranslator_config_get_string("runtime/filename");
-	gtranslator_config_close();
 
 	/*
 	 * Test if we've got a filename and for equality.
